# Clean Actions

A Tool for generating Github Action Workflows following DRY principals.

## Install

\#TODO

## Usage

\#TODO

### Advanced

For advanced examples, you can view the [test cases][test-cases] for a full overview
of functionality available.

## Contributing

Contributions are welcome! See the [Contributing Guide][contributing] for more details

[test-cases]: ./tests/cases/
[contributing]: ./contributing.md
